Something I want to talk about before we get too deep into this is the name of this package. I don't think that Team Build is actually what the best name for this is. It was just my initial thought. We should work through this.

Also, I want to talk about the command line interface versus a TUIs as a possible use case for this project or coding in general. I need to understand what the benefits are of this versus CLI versus TUIs versus VS Code, IDEs, all that stuff. I want to explore that more. Can you do an internet research to get as much information as you can about this before we do it?